==> haskell-filtrable-0.1.6.0-282.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-filtrable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filtrable
version:              0.1.6.0
visibility:           public
id:                   filtrable-0.1.6.0-IOYZfNkyhv6IpXIpnLCXcC
key:                  filtrable-0.1.6.0-IOYZfNkyhv6IpXIpnLCXcC
license:              BSD-3-Clause
maintainer:           strake888@gmail.com
author:               M Farkas-Dyck
homepage:             https://github.com/strake/filtrable.hs
synopsis:             Class of filtrable containers
description:          See "Data.Filtrable".
category:             Data
abi:                  8a471a4d5081fce8857349168f46d3d5
exposed:              True
exposed-modules:      Data.Filtrable
hidden-modules:       Data.Set.Private
import-dirs:          /usr/lib/ghc-9.6.6/site-local/filtrable-0.1.6.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/filtrable-0.1.6.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/filtrable-0.1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filtrable
hs-libraries:         HSfiltrable-0.1.6.0-IOYZfNkyhv6IpXIpnLCXcC
depends:              base-4.18.2.1 containers-0.6.7 transformers-0.6.1.0
haddock-interfaces:   /usr/share/doc/haskell-filtrable/html/filtrable.haddock
haddock-html:         /usr/share/doc/haskell-filtrable/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filtrable-0.1.6.0-283-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-filtrable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 filtrable
version:              0.1.6.0
visibility:           public
id:                   filtrable-0.1.6.0-8bdKxzzk7McKxAYa1UD30S
key:                  filtrable-0.1.6.0-8bdKxzzk7McKxAYa1UD30S
license:              BSD-3-Clause
maintainer:           strake888@gmail.com
author:               M Farkas-Dyck
homepage:             https://github.com/strake/filtrable.hs
synopsis:             Class of filtrable containers
description:          See "Data.Filtrable".
category:             Data
abi:                  b5811e16641900e4f3d3e30c1b8b5ff2
exposed:              True
exposed-modules:      Data.Filtrable
hidden-modules:       Data.Set.Private
import-dirs:          /usr/lib/ghc-9.6.6/site-local/filtrable-0.1.6.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/filtrable-0.1.6.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/filtrable-0.1.6.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-filtrable
hs-libraries:         HSfiltrable-0.1.6.0-8bdKxzzk7McKxAYa1UD30S
depends:              base-4.18.2.1 containers-0.6.7 transformers-0.6.1.0
haddock-interfaces:   /usr/share/doc/haskell-filtrable/html/filtrable.haddock
haddock-html:         /usr/share/doc/haskell-filtrable/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
